###################################################
### chunk number 1: preliminaries
###################################################
set.seed(1071)
#library(vcd)
library(vcdExtra)
#data(Titanic)
data(HairEyeColor)
data(PreSex)
data(Arthritis)
art <- xtabs(~Treatment + Improved, data = Arthritis)


###################################################
### chunk number 2: case-form
###################################################
names(Arthritis)      # show the variables
str(Arthritis)        # show the structure
head(Arthritis,5)     # first 5 observations, same as Arthritis[1:5,] 


###################################################
### chunk number 3: frequency-form
###################################################
# Agresti (2002), table 3.11, p. 106
GSS <- data.frame(
  expand.grid(sex=c("female", "male"), 
              party=c("dem", "indep", "rep")),
  count=c(279,165,73,47,225,191))
GSS
names(GSS)
str(GSS)
sum(GSS$count)


###################################################
### chunk number 4: table-form1
###################################################
str(HairEyeColor)                      # show the structure
sum(HairEyeColor)                      # number of cases
sapply(dimnames(HairEyeColor), length) # table dimension sizes


###################################################
### chunk number 5: table-form2
###################################################
## A 4 x 4 table  Agresti (2002, Table 2.8, p. 57) Job Satisfaction
JobSat <- matrix(c(1,2,1,0, 3,3,6,1, 10,10,14,9, 6,7,12,11), 4, 4)
dimnames(JobSat) = list(income=c("< 15k", "15-25k", "25-40k", "> 40k"),
                satisfaction=c("VeryD", "LittleD", "ModerateS", "VeryS"))
JobSat


###################################################
### chunk number 6: table-form3
###################################################
JobSat <- as.table(JobSat)
str(JobSat)


###################################################
### chunk number 7: relevel eval=FALSE
###################################################
## dimnames(JobSat)$income<-c(7.5,20,32.5,60)
## dimnames(JobSat)$satisfaction<-1:4


###################################################
### chunk number 8: reorder1
###################################################
HairEyeColor <- HairEyeColor[, c(1,3,4,2), ]
str(HairEyeColor)


###################################################
### chunk number 9: reorder2 eval=FALSE
###################################################
## Arthritis <- read.csv("arthritis.txt",header=TRUE)
## Arthritis$Improved <- ordered(Arthritis$Improved, levels=c("None", "Some", "Marked"))


###################################################
### chunk number 10: Arthritis
###################################################
mosaic(art, gp = shading_max, split_vertical = TRUE, main="Arthritis: [Treatment] [Improved]")


###################################################
### chunk number 11: reorder3
###################################################
UCB <- aperm(UCBAdmissions, c(2, 1, 3))
dimnames(UCB)[[2]] <- c("Yes", "No")
names(dimnames(UCB)) <- c("Sex", "Admit?", "Department")
ftable(UCB)


###################################################
### chunk number 12: structable
###################################################
structable(HairEyeColor)                   # show the table: default
structable(Hair+Sex ~ Eye, HairEyeColor)   # specify col ~ row variables


###################################################
### chunk number 13: structable1 eval=FALSE
###################################################
## HSE < - structable(Hair+Sex ~ Eye, HairEyeColor)   # save structable object
## mosaic(HSE)                                        # plot it


###################################################
### chunk number 14: setup
###################################################
 n=500
 A <- factor(sample(c("a1","a2"), n, rep=TRUE))
 B <- factor(sample(c("b1","b2"), n, rep=TRUE))
 C <- factor(sample(c("c1","c2"), n, rep=TRUE))
 mydata <- data.frame(A,B,C)


###################################################
### chunk number 15: table-ex1
###################################################
# 2-Way Frequency Table
attach(mydata)
mytable <- table(A,B)   # A will be rows, B will be columns
mytable                 # print table

margin.table(mytable, 1) # A frequencies (summed over B)
margin.table(mytable, 2) # B frequencies (summed over A)

prop.table(mytable)    # cell percentages
prop.table(mytable, 1) # row percentages
prop.table(mytable, 2) # column percentages


###################################################
### chunk number 16: table-ex2
###################################################
# 3-Way Frequency Table
mytable <- table(A, B, C)
ftable(mytable)


###################################################
### chunk number 17: xtabs-ex1
###################################################
# 3-Way Frequency Table
mytable <- xtabs(~A+B+C, data=mydata)
ftable(mytable)    # print table
summary(mytable)   # chi-square test of indepedence


###################################################
### chunk number 18: xtabs-ex2
###################################################
(GSStab <- xtabs(count ~ sex + party, data=GSS))
summary(GSStab)


###################################################
### chunk number 19: convert-ex1
###################################################
as.data.frame(GSStab)


###################################################
### chunk number 20: convert-ex2
###################################################
Art.tab <-with(Arthritis, table(Treatment, Sex, Improved))
str(Art.tab)
ftable(Art.tab)


###################################################
### chunk number 21: convert-ex3
###################################################
Art.df <- expand.dft(Art.tab)
str(Art.df)


###################################################
### chunk number 22: tv1
###################################################
tv.data<-read.table(system.file("data","tv.dat",package="vcdExtra"))
head(tv.data,5)


###################################################
### chunk number 23: tv2 eval=FALSE
###################################################
## tv.data<-read.table("C:/R/data/tv.dat")


###################################################
### chunk number 24: tv2
###################################################
TV <- array(tv.data[,5], dim=c(5,11,5,3))                                        

dimnames(TV) <- list(c("Monday","Tuesday","Wednesday","Thursday","Friday"), 
                c("8:00","8:15","8:30","8:45","9:00","9:15","9:30",         
                "9:45","10:00","10:15","10:30"),                            
                c("ABC","CBS","NBC","Fox","Other"), c("Off","Switch","Persist"))
names(dimnames(TV))<-c("Day", "Time", "Network", "State")


###################################################
### chunk number 25: tv3
###################################################
TV <- TV[,,1:3,]     # keep only ABC, CBS, NBC
TV <- TV[,,,3]       # keep only Persist -- now a 3 way table
structable(TV)


###################################################
### chunk number 26: tv4
###################################################
TV.df <- as.data.frame.table(TV)
levels(TV.df$Time) <- c(rep("8:00-8:59",4),rep("9:00-9:59",4), rep("10:00-10:44",3))
TV2 <- xtabs(Freq ~ Day + Time + Network, TV.df)
structable(Day ~ Time+Network,TV2)


###################################################
### chunk number 27: xtabs-ex2
###################################################
# 2-Way Cross Tabulation
library(gmodels)
CrossTable(GSStab,prop.t=FALSE,prop.r=FALSE,prop.c=FALSE)


###################################################
### chunk number 28: chisq
###################################################
(HairEye <- margin.table(HairEyeColor, c(1, 2)))
chisq.test(HairEye)


###################################################
### chunk number 29: fisher
###################################################
fisher.test(GSStab)


###################################################
### chunk number 30:  eval=FALSE
###################################################
## fisher.test(HairEye)


###################################################
### chunk number 31: 
###################################################
cat(try(fisher.test(HairEye)))


###################################################
### chunk number 32: mantel1
###################################################
## UC Berkeley Student Admissions
mantelhaen.test(UCBAdmissions)


###################################################
### chunk number 33: mantel2
###################################################
oddsratio(UCBAdmissions, log=FALSE)
lor <- oddsratio(UCBAdmissions)  # capture log odds ratios
summary(lor)
woolf_test(UCBAdmissions) 


###################################################
### chunk number 34: fourfold1
###################################################
col <- c("#99CCFF", "#6699CC", "#F9AFAF", "#6666A0", "#FF0000", "#000080")
fourfold(UCB,mfrow=c(2,3), color=col)


###################################################
### chunk number 35: fourfold2 eval=FALSE
###################################################
## cotabplot(UCB, panel = cotab_fourfold)


###################################################
### chunk number 36: oddsratio0 eval=FALSE
###################################################
## plot(lor, xlab="Department", ylab="Log Odds Ratio (Admit | Gender)")


###################################################
### chunk number 37: oddsratio
###################################################
plot(lor, xlab="Department", ylab="Log Odds Ratio (Admit | Gender)")


###################################################
### chunk number 38: assoc1
###################################################
assocstats(GSStab)


###################################################
### chunk number 39: gamma
###################################################
GKgamma(JobSat)


###################################################
### chunk number 40: kappa
###################################################
(K <- Kappa(SexualFun))
confint(K)


###################################################
### chunk number 41: agreesex
###################################################
agree <- agreementplot(SexualFun, main="Is sex fun?")
unlist(agree)


###################################################
### chunk number 42: ca1
###################################################
library(ca)
ca(HairEye)


###################################################
### chunk number 43: ca-haireye0 eval=FALSE
###################################################
## plot(ca(HairEye), main="Hair Color and Eye Color")
## title(xlab="Dim 1 (89.4%)", ylab="Dim 2 (9.5%)")


###################################################
### chunk number 44: ca-haireye
###################################################
plot(ca(HairEye), main="Hair Color and Eye Color")
title(xlab="Dim 1 (89.4%)", ylab="Dim 2 (9.5%)")


###################################################
### chunk number 45: loglm-hec1
###################################################
library(MASS)
## Independence model of hair and eye color and sex.  
hec.1 <- loglm(~Hair+Eye+Sex, data=HairEyeColor)
hec.1


###################################################
### chunk number 46: loglm-hec2
###################################################
## Conditional independence
hec.2 <- loglm(~(Hair + Eye) * Sex, data=HairEyeColor)
hec.2


###################################################
### chunk number 47: loglm-hec3
###################################################
## Joint independence model.  
hec.3 <- loglm(~Hair*Eye + Sex, data=HairEyeColor)
hec.3


###################################################
### chunk number 48: loglm-anova
###################################################
anova(hec.1, hec.2, hec.3)


###################################################
### chunk number 49: mental1
###################################################
str(Mental)
xtabs(Freq ~ mental+ses, data=Mental)   # display the frequency table


###################################################
### chunk number 50: mental2
###################################################
indep <- glm(Freq ~ mental + ses, family = poisson, data = Mental)  # independence model


###################################################
### chunk number 51: mental3
###################################################
# Use integer scores for rows/cols 
Cscore <- as.numeric(Mental$ses)
Rscore <- as.numeric(Mental$mental)	


###################################################
### chunk number 52: mental4
###################################################
# column effects model (ses)
coleff <- glm(Freq ~ mental + ses + Rscore:ses, family = poisson, data = Mental)

# row effects model (mental)
roweff <- glm(Freq ~ mental + ses + mental:Cscore, family = poisson, data = Mental)

# linear x linear association
linlin <- glm(Freq ~ mental + ses + Rscore:Cscore, family = poisson, data = Mental)

# compare models using AIC
AIC(indep, roweff, coleff, linlin)


###################################################
### chunk number 53: mental5
###################################################
anova(indep, linlin, coleff, test="Chisq")	
anova(indep, linlin, roweff, test="Chisq")	


###################################################
### chunk number 54: Arthritis1 eval=FALSE
###################################################
## mosaic(art, gp = shading_max, split_vertical = TRUE, 
##        main="Arthritis: [Treatment] [Improved]")


###################################################
### chunk number 55: art1
###################################################
summary(art)


###################################################
### chunk number 56: art21
###################################################
mosaic(art, gp = shading_max, split_vertical = TRUE, 
       main="Arthritis: gp = shading_max")


###################################################
### chunk number 57: art22
###################################################
mosaic(art, gp = shading_Friendly, split_vertical = TRUE, 
       main="Arthritis: gp = shading_Friendly")


###################################################
### chunk number 58: hec-mosaic eval=FALSE
###################################################
## # mosaic plots, using plot.loglm() method
## plot(hec.1, main="model: [Hair][Eye][Sex]")
## plot(hec.2, main="model: [HairSex][EyeSex]")
## plot(hec.3, main="model: [HairEye][Sex]")


###################################################
### chunk number 59: hec1
###################################################
plot(hec.1, main="model: [Hair][Eye][Sex]")


###################################################
### chunk number 60: hec2
###################################################
plot(hec.2, main="model: [HairSex][EyeSex]")


###################################################
### chunk number 61: hec3
###################################################
plot(hec.3, main="model: [HairSex][EyeSex]")


###################################################
### chunk number 62: TV-mosaic0 eval=FALSE
###################################################
## dimnames(TV2)$Time <- c("8", "9", "10")     # re-level for mosaic display
## mosaic(~ Day + Network + Time, data=TV2, expected=~Day:Time + Network, 
##          legend=FALSE, gp=shading_Friendly)


###################################################
### chunk number 63: TV-mosaic
###################################################
dimnames(TV2)$Time <- c("8", "9", "10")     # re-level for mosaic display
mosaic(~ Day + Network + Time, data=TV2, expected=~Day:Time + Network, 
         legend=FALSE, gp=shading_Friendly)


###################################################
### chunk number 64: TV-mosaic1 eval=FALSE
###################################################
## mosaic(~ Day + Network + Time, data=TV2, 
##          expected=~Day:Time + Day:Network + Time:Network, 
##          legend=FALSE, gp=shading_Friendly)


###################################################
### chunk number 65: mental-plots eval=FALSE
###################################################
## long.labels <- list(set_varnames = c(mental="Mental Health Status", ses="Parent SES"))
## mosaic(indep,residuals_type="rstandard", labeling_args = long.labels, 
##      labeling=labeling_residuals,
##      main="Mental health data: Independence")
## 
## mosaic(linlin,residuals_type="rstandard", labeling_args = long.labels, 
##      labeling=labeling_residuals, suppress=1, gp=shading_Friendly,
##      main="Mental health data: Linear x Linear")


###################################################
### chunk number 66: mental-plots1
###################################################
long.labels <- list(set_varnames = c(mental="Mental Health Status", ses="Parent SES"))
mosaic(indep,residuals_type="rstandard", labeling_args = long.labels, 
    labeling=labeling_residuals,
       main="Mental health data: Independence")


###################################################
### chunk number 67: mental-plots2
###################################################
long.labels <- list(set_varnames = c(mental="Mental Health Status", ses="Parent SES"))
mosaic(linlin,residuals_type="rstandard", labeling_args = long.labels, 
		labeling=labeling_residuals, suppress=1, gp=shading_Friendly,
		main="Mental health data: Linear x Linear")


###################################################
### chunk number 68: mental-RC1 eval=FALSE
###################################################
## Mental$mental <- C(Mental$mental, treatment)
## Mental$ses <- C(Mental$ses, treatment)
## RC1model <- gnm(Freq ~ mental + ses + Mult(mental, ses),
##                 family = poisson, data = Mental)
## mosaic(RC1model, residuals_type="rstandard", labeling_args = long.labels, 
##        labeling=labeling_residuals, suppress=1, gp=shading_Friendly,
##        main="Mental health data: RC(1) model")


###################################################
### chunk number 69: reorder3a
###################################################
UCB <- aperm(UCBAdmissions, c(2, 1, 3))
names(dimnames(UCB)) <- c("Sex", "Admit?", "Department")
dimnames(UCB)[[2]] <- c("Yes", "No")


###################################################
### chunk number 70: reorder3b
###################################################
vnames <- list(set_varnames = c(Admit="Admission", Gender="Sex", Dept="Department"))

lnames <- list(Admit = c("Yes", "No"),
              Gender = c("Males", "Females"),
              Dept = LETTERS[1:6])

mosaic(UCBAdmissions, labeling_args=vnames, set_labels=lnames)


###################################################
### chunk number 71: TV-mosaic2
###################################################
dimnames(TV2)$Time <- c("8", "9", "10")     # re-level for mosaic display
mosaic(~ Day + Network + Time, data=TV2, expected=~Day:Time + Network, 
         legend=FALSE, gp=shading_Friendly, 
         labeling_args=list(abbreviate=c(Day=3)) )


###################################################
### chunk number 72: spine1
###################################################
(spine(Improved ~ Age, data = Arthritis, breaks = 3))
(spine(Improved ~ Age, data = Arthritis, breaks = "Scott"))


###################################################
### chunk number 73: spine2
###################################################
(spine(Improved ~ Age, data = Arthritis, breaks = 3))


###################################################
### chunk number 74: spine3
###################################################
(spine(Improved ~ Age, data = Arthritis, breaks = "Scott"))


###################################################
### chunk number 75: cdplot
###################################################
cdplot(Improved ~ Age, data = Arthritis)
with(Arthritis, rug(jitter(Age), col="white", quiet=TRUE))


###################################################
### chunk number 76: cdplot1
###################################################
cdplot(Improved ~ Age, data = Arthritis)
with(Arthritis, rug(jitter(Age), col="white", quiet=TRUE))


